@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::As::Parsed; # git description: v1.72-7-g8682f63
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Tie::IxHash;
 
@@ -763,11 +763,11 @@ __END__
 
 =head1 NAME
 
-YAML::As::Parsed - Read/Write YAML files with as little code as possible
+YAML::As::Parsed - Read/Write YAML predictably
 
 =head1 VERSION
 
-version 1.73
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -805,13 +805,6 @@ See L<YAML::Tiny> for documentation.
 
 L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=YAML-As-Parsed>
 
-=begin html
-
-For other issues, or commercial enhancement or support, please contact
-<a href="http://ali.as/">Adam Kennedy</a> directly.
-
-=end html
-
 =head1 AUTHOR
 
 LNATION 
@@ -836,8 +829,6 @@ LNATION
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2013 Adam Kennedy.
-
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
